Kopf: Kubernetes Operators Framework
====================================

.. toctree::
   :maxdepth: 2
   :caption: First steps:

   install

.. toctree::
   :maxdepth: 2
   :caption: Tutorial:

   concepts
   walkthrough/problem
   walkthrough/prerequisites
   walkthrough/resources
   walkthrough/starting
   walkthrough/creation
   walkthrough/updates
   walkthrough/diffs
   walkthrough/deletion
   deployment
   cleanup

.. toctree::
   :maxdepth: 2
   :caption: Features:

   handlers
   hierarchies
   async
   loading
   peering
   scopes
   errors
   events
   testing
   configuring
   embedding

.. toctree::
   :maxdepth: 2
   :caption: Maintenance:

   continuity
   idempotence
   troubleshooting

.. toctree::
   :maxdepth: 2
   :caption: Developer Manual:

   minikube
   contributing
   packages/kopf

.. toctree::
   :maxdepth: 2
   :caption: About Kopf:

   vision
   naming
   alternatives


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
